from OFS.Folder import Folder
from Globals import Persistent
from Acquisition import Implicit
from Products.PageTemplates.PageTemplateFile import PageTemplateFile
import Shared.DC.ZRDB.DA
from request import *

manage_addPhotoForm = PageTemplateFile(
    'www/photoscommandesAdd', globals(), __name__='manage_addPhotoForm')

def manage_addPhoto(self, id, images_path, REQUEST, connection_id='', title=''):
	""" Method for adding a Photos Commandes object """
	newPhoto = PhotosCommandes(id, images_path, connection_id, title)
	self._setObject(id, newPhoto)
	return self.manage_main(self, REQUEST)
	

class PhotosCommandes(Folder, Persistent, Implicit):
	""" Photos Commandes object """

	def register_my_sql(self, connection_id):
		""" Register my sqls request """
		for id in requests.keys():
			#params = getattr(self, '%s_params' % id)
			zsql = Shared.DC.ZRDB.DA.DA(id, '', connection_id, requests[id]['params'], requests[id]['request'])
			setattr(self, id, zsql)
			try:
				self.sql.index(id)
			except:
				self.sql.append(id)
		self.__changed__(1)

	def __init__(self, id, images_path, connection_id='', title=''):
		""" Method to init Photos Commandes object """
		self.id = id
		self.title = title
		self.images_path = images_path
		self.connection_id = connection_id
		self.sql = []
		self.register_my_sql(self.connection_id)

	meta_type = "Photos Commandes"

	manage_options = ((
		{'label':'Edit', 'action':'manage_editPhotoForm'},
		{'label':'Sql', 'action':'manage_sqlPhotoForm'},
		) + Folder.manage_options)

	def manage_editPhoto(self, images_path, REQUEST, connection_id='', title=''):
		""" Method to edit Photos Commandes object """
		self.title = title
		self.images_path = images_path
		self.connection_id = connection_id
		self.register_my_sql(self.connection_id)
		return self.manage_editPhotoForm(self, REQUEST)

	#Scripts
	def nb_photo(self):
		""" Show number of photos """
		return self.count_photo().dictionaries()[0]['count(PHT_ID)']

	def show_photo(self, id):
		""" Show a photo """
		try:
			return self.select_photo(PHT_ID=id).dictionaries()[0]
		except:
			return {'PHT_FICHIER': '', 'PHT_DESC': '', 'PHT_ID': ''}

	def show_parent(self, parent_id):
		""" Show a parent """
		return self.select_parent(PRT_ID=parent_id).dictionaries()[0]

	def show_parents(self):
		""" Show all parents """
		parents = []

		for parent in self.select_parent():
		   nom_complet = '%s %s' % (parent['PRT_NOM'], parent['PRT_ENFANT'])
		   id = parent['PRT_ID']
		   prt_list = { 'id':  id, 'nom': nom_complet}
		   parents.append(prt_list)

		return parents

	#Formulaire
	def create_parent(self, CLS_ID=0):
		""" Create parent """
		return self.create_parent_form(CLS_ID=CLS_ID)

	def create_one_commande(self, PRT_ID=0, CMD_ID=0):
		""" Create parent's commande """
		return self.create_one_commande_form(PRT_ID=PRT_ID, CMD_ID=CMD_ID)

	def view_list_parents(self, commande=0):
		""" Show parents parents """
		return self.view_list_parents_form(commande=commande)

	def view_one_commande(self, parent_id=0, commande=0):
		""" Show parent's commande """
		return self.view_one_commande_form(parent_id=parent_id, commande=commande)

	def view_commande(self, commande=0):
		""" Voir les photos des commandes """
		return self.view_commande_form(commande=commande)

	# Traitement
	def traitement_creer_classe(self, classe):
		""" Traitement creation d'une classe """
		self.insert_classe(CLS_NOM=classe)

		return self.create_classe()

	def traitement_creer_parent(self, classe, nom, prenom):
		""" Traitement creation d'un parent """
		self.insert_parent(
			CLS_ID=classe,
			PRT_NOM=nom,
			PRT_ENFANT=prenom)

		return self.create_parent_form(CLS_ID=classe)

	def traitement_creer_commande(self, commande):
		""" Traitement creation d'une commande """
		self.insert_commande(CMD_DATE=commande)

		return self.create_commande()

	def traitement_one_commande(self, enfant, number, photo, commande):
		""" Traitement creation d'une commande """
		lnumber = number.keys()

		for v in lnumber:
		   if len(photo[v]):
		      #print "PRT_ID = %s, CMD_ID = %s, PHT_ID = %s, QPH_NOMBRE = %s" % (enfant, commande, photo[v], number[v])
		      self.insert_one_commande(PRT_ID=enfant, 
						    CMD_ID=commande, 
						    PHT_ID=photo[v], 
						    QPH_NOMBRE=number[v])

		return self.create_one_commande(PRT_ID=enfant, CMD_ID=commande)

	def list_all_commandes(self, commande):
		""" Traitement creation d'une commande """
		photo_hash = {}
		commandes_hash = {}
		commandes = []

		for com in self.select_commande_detail(CMD_ID=commande):
		   if commandes_hash.has_key(com['PHT_ID']):
		      nbr = commandes_hash[com['PHT_ID']]
		   else:
		      nbr = 0
		   nbr += com['QPH_NOMBRE']
		   commandes_hash[com['PHT_ID']] = nbr
		   photo_hash[com['PHT_ID']] = com['PHT_FICHIER']

		values = []
		for x in commandes_hash.values():
		    if x not in values:
			values.append(x)

		keys = []
		for x in commandes_hash.keys():
		    if x not in keys:
			keys.append(x)

		keys.sort()
		values.sort()
		values.reverse()

		for vl in values:
		    for k in keys:
		       v = commandes_hash[k]
		       if v == vl:
			  commandes.append({'photo': k, 'number': v, 'fichier': photo_hash[k]})

		return commandes

	def make_cd(self, commande, path):
		""" Preparer la creation du CD 2eme """
		result = self.select_commande_cd(CMD_ID=commande)
		repertoire={}
		printed = ''

		for l in result:
		   nom = l.PRT_NOM.lower()[:8]
		   if not repertoire.has_key(nom):
		      printed += "mkdir -p %s/%s\n" % (path, nom)
		      repertoire[nom] = 1

		for l in result:
		   nom = l.PRT_NOM.lower()[:8]
		   if l.QPH_NOMBRE <= 1:
		      printed += 'cp %s %s/%s/\n' % (l.PHT_FICHIER, path, nom)
		   else:
		      printed += 'cp %s %s/%s/\n' % (l.PHT_FICHIER, path, nom)
		      for i in range(1, l.QPH_NOMBRE):
			 fichier = l.PHT_FICHIER.replace('_', str(i))
			 printed += 'cp %s %s/%s/%s\n' % (l.PHT_FICHIER, path, nom, fichier)

		return printed

	def make_cd1(self, commande, path):
		""" Preparer la creation du CD 1ere """
		photos = self.list_all_commandes(commande)
		printed = ''

		number = []
		for photo in photos:
		   num = photo['number']
		   if not num in number:
		      number.append(num)

		for num in number:
		   printed += 'mkdir -p %s/%s%s\n' % (path, num, self.images_path)

		photos = self.list_all_commandes(commande)

		for photo in photos:
		   printed += 'cp %s %s/%s%s/\n' % (photo['fichier'], path, photo['number'], self.images_path)

		return printed



	# Web method
	manage_editPhotoForm = PageTemplateFile('www/photoscommandesEdit', globals())
	manage_sqlPhotoForm = PageTemplateFile('www/photoscommandesSql', globals())
	main_template = PageTemplateFile('www/main_template', globals())
	index_html = PageTemplateFile('www/index_html', globals())
	create_classe = PageTemplateFile('www/create_classe', globals())
	create_parent_form = PageTemplateFile('www/create_parent_form', globals())
	create_commande = PageTemplateFile('www/create_commande', globals())
	view_photos = PageTemplateFile('www/view_photos', globals())
	view_all_photos = PageTemplateFile('www/view_all_photos', globals())
	create_one_commande_form = PageTemplateFile('www/create_one_commande_form', globals())
	view_commande_form = PageTemplateFile('www/view_commande_form', globals())
	make_cd_form = PageTemplateFile('www/make_cd_form', globals())
	view_one_commande_form = PageTemplateFile('www/view_one_commande_form', globals())
	view_list_parents_form = PageTemplateFile('www/view_list_parents_form', globals())
